@@ -121,17 +121,6 @@ public class ProcessInstanceListPresenter extends AbstractMultiGridPresenter<Pro
                     dataSetQueryHelper.setLastSortOrder(SortOrder.ASCENDING);
                 }
 
-                final List<ColumnFilter> filters = getColumnFilters(textSearchStr);
-                if (filters.isEmpty() == false) {
-                    if (currentTableSettings.getDataSetLookup().getFirstFilterOp() != null) {
-                        currentTableSettings.getDataSetLookup().getFirstFilterOp().addFilterColumn(OR(filters));
-                    } else {
-                        final DataSetFilter filter = new DataSetFilter();
-                        filter.addFilterColumn(OR(filters));
-                        currentTableSettings.getDataSetLookup().addOperation(filter);
-                    }
-                }
-
                 dataSetQueryHelper.setCurrentTableSettings(currentTableSettings);
                 dataSetQueryHelper.setDataSetHandler(currentTableSettings);
                 dataSetQueryHelper.lookupDataSet(visibleRange.getStart(),
@@ -144,30 +133,6 @@ public class ProcessInstanceListPresenter extends AbstractMultiGridPresenter<Pro
         }
     }
 
-    protected List<ColumnFilter> getColumnFilters(final String searchString) {
-        final List<ColumnFilter> filters = new ArrayList<ColumnFilter>();
-        if (searchString != null && searchString.trim().length() > 0) {
-            try {
-                final Long instanceId = Long.valueOf(searchString.trim());
-                filters.add(equalsTo(COLUMN_PROCESS_INSTANCE_ID,
-                                     instanceId));
-            } catch (NumberFormatException ex) {
-                filters.add(equalsTo(COLUMN_PROCESS_ID,
-                                     searchString));
-                filters.add(likeTo(COLUMN_PROCESS_NAME,
-                                   "%" + searchString.toLowerCase() + "%",
-                                   false));
-                filters.add(likeTo(COLUMN_PROCESS_INSTANCE_DESCRIPTION,
-                                   "%" + searchString.toLowerCase() + "%",
-                                   false));
-                filters.add(likeTo(COLUMN_IDENTITY,
-                                   "%" + searchString.toLowerCase() + "%",
-                                   false));
-            }
-        }
-        return filters;
-    }
-
     protected DataSetReadyCallback createDataSetDomainSpecificCallback(final int startRange,
                                                                        final FilterSettings tableSettings,
                                                                        boolean lastPage) {
@@ -624,6 +589,7 @@ public class ProcessInstanceListPresenter extends AbstractMultiGridPresenter<Pro
 
         view.addDateRangeFilter(constants.Start_Date(),
                                 constants.Start_Date_Placeholder(),
+                                true,
                                 v -> addAdvancedSearchFilter(between(COLUMN_START,
                                                                      v.getStartDate(),
                                                                      v.getEndDate())),
@@ -634,6 +600,7 @@ public class ProcessInstanceListPresenter extends AbstractMultiGridPresenter<Pro
 
         view.addDateRangeFilter(constants.Last_Modification_Date(),
                                 constants.Last_Modification_Date_Placeholder(),
+                                true,
                                 v -> addAdvancedSearchFilter(between(COLUMN_LAST_MODIFICATION_DATE,
                                                                      v.getStartDate(),
                                                                      v.getEndDate())),
