@@ -31,13 +31,12 @@ import org.jboss.errai.ui.shared.api.annotations.Bundle;
 import org.jbpm.workbench.client.i18n.Constants;
 import org.jbpm.workbench.client.perspectives.ProcessAdminSettingsPerspective;
 import org.jbpm.workbench.client.perspectives.TaskAdminSettingsPerspective;
-import org.kie.workbench.common.screens.search.client.menu.SearchMenuBuilder;
+import org.kie.workbench.common.workbench.client.admin.DefaultAdminPageHelper;
 import org.kie.workbench.common.workbench.client.entrypoint.DefaultWorkbenchEntryPoint;
 import org.kie.workbench.common.workbench.client.menu.DefaultWorkbenchFeaturesMenusHelper;
-import org.uberfire.client.mvp.AbstractWorkbenchPerspectiveActivity;
 import org.uberfire.client.mvp.ActivityBeansCache;
 import org.uberfire.client.views.pfly.menu.MainBrand;
-import org.uberfire.client.workbench.widgets.menu.WorkbenchMenuBarPresenter;
+import org.uberfire.client.workbench.widgets.menu.megamenu.WorkbenchMegaMenuPresenter;
 import org.uberfire.mvp.impl.DefaultPlaceRequest;
 import org.uberfire.workbench.model.menu.MenuFactory;
 import org.uberfire.workbench.model.menu.MenuItem;
@@ -57,36 +56,36 @@ public class ShowcaseEntryPoint extends DefaultWorkbenchEntryPoint {
 
     protected DefaultWorkbenchFeaturesMenusHelper menusHelper;
 
-    protected WorkbenchMenuBarPresenter menuBar;
+    protected WorkbenchMegaMenuPresenter menuBar;
+
+    protected DefaultAdminPageHelper adminPageHelper;
 
     @Inject
     public ShowcaseEntryPoint(final Caller<AppConfigService> appConfigService,
                               final ActivityBeansCache activityBeansCache,
                               final SyncBeanManager iocManager,
                               final User identity,
+                              final DefaultAdminPageHelper adminPageHelper,
                               final DefaultWorkbenchFeaturesMenusHelper menusHelper,
-                              final WorkbenchMenuBarPresenter menuBar) {
+                              final WorkbenchMegaMenuPresenter menuBar) {
         super(appConfigService,
               activityBeansCache);
         this.iocManager = iocManager;
         this.identity = identity;
         this.menusHelper = menusHelper;
         this.menuBar = menuBar;
+        this.adminPageHelper = adminPageHelper;
     }
 
     @Override
     protected void setupMenu() {
-
-        final AbstractWorkbenchPerspectiveActivity defaultPerspective = menusHelper.getDefaultPerspectiveActivity();
         final Menus menus = MenuFactory
-                .newTopLevelMenu(constants.Home()).place(new DefaultPlaceRequest(defaultPerspective.getIdentifier())).endMenu()
                 .newTopLevelMenu(constants.Authoring()).withItems(getAuthoringViews()).endMenu()
                 .newTopLevelMenu(constants.Deploy()).withItems(getDeploymentViews()).endMenu()
                 .newTopLevelMenu(constants.Process_Management()).withItems(getProcessManagementViews()).endMenu()
                 .newTopLevelMenu(constants.Work()).withItems(getWorkViews()).endMenu()
                 .newTopLevelMenu(constants.Dashboards()).withItems(getDashboardsViews()).endMenu()
                 .newTopLevelMenu(constants.Extensions()).withItems(menusHelper.getExtensionsViews()).endMenu()
-                .newTopLevelCustomMenu(iocManager.lookupBean(SearchMenuBuilder.class).getInstance()).endMenu()
                 .build();
 
         menuBar.addMenus(menus);
@@ -97,6 +96,11 @@ public class ShowcaseEntryPoint extends DefaultWorkbenchEntryPoint {
         menusHelper.addUtilitiesMenuItems();
     }
 
+    @Override
+    protected void setupAdminPage() {
+        adminPageHelper.setup();
+    }
+
     protected List<? extends MenuItem> getAuthoringViews() {
         return Arrays.asList(
                 MenuFactory.newSimpleItem(constants.Project_Authoring()).perspective(LIBRARY).endMenu().build().getItems().get(0),
